@@ -41,11 +41,13 @@ setClass("Splits", representation("raw"))
 #' print(moreSplits, details = TRUE)
 #' match(splits, moreSplits)
 #' moreSplits %in% splits
+#' 
+#' as.Splits("....**", letters[1:6])
 #'
 #' @family Splits operations
 #' @name Splits
 #' @export
-as.Splits <- function(x, tipLabels = NULL, ...) UseMethod('as.Splits')
+as.Splits <- function(x, tipLabels = NULL, ...) UseMethod("as.Splits")
 
 #' @rdname Splits
 #' @param asSplits Logical specifying whether to return a `Splits` object,
@@ -102,7 +104,7 @@ edge_to_splits <- function(edge, edgeOrder, tipLabels = NULL, asSplits = TRUE,
     structure(splits,
               nTip = nTip,
               tip.label = tipLabels,
-              class = 'Splits')
+              class = "Splits")
   }
   else {
     splits
@@ -125,19 +127,19 @@ as.Splits.Splits <- function(x, tipLabels = NULL, ...) {
     x
   } else {
     tipLabels <- TipLabels(tipLabels, single = TRUE)
-    oldLabels <- attr(x, 'tip.label')
+    oldLabels <- attr(x, "tip.label")
     if (is.null(oldLabels)) {
-      nTip <- attr(x, 'nTip')
+      nTip <- attr(x, "nTip")
       if (length(tipLabels) == nTip) {
-        attr(x, 'tip.label') <- tipLabels
+        attr(x, "tip.label") <- tipLabels
         x
       } else {
         stop(length(tipLabels), " labels provided; expecting ", nTip)
       }
     } else if (!identical(oldLabels, tipLabels)) {
-      nTip <- attr(x, 'nTip')
+      nTip <- attr(x, "nTip")
       if (length(x) == 0) {
-        attr(x, 'tip.label') <- tipLabels
+        attr(x, "tip.label") <- tipLabels
         x
       } else {
         if (all(oldLabels %in% tipLabels) && all(tipLabels %in% oldLabels)) {
@@ -157,16 +159,16 @@ as.Splits.Splits <- function(x, tipLabels = NULL, ...) {
 #' @rdname Splits
 #' @export
 as.Splits.list <- function(x, tipLabels = NULL, asSplits = TRUE, ...) {
-  if (inherits(x[[1]], 'phylo')) {
+  if (inherits(x[[1]], "phylo")) {
     if (is.null(tipLabels)) {
       tipLabels <- x[[1]][["tip.label"]]
     }
     lapply(x, as.Splits, tipLabels = tipLabels, asSplits = asSplits)
-  } else if (inherits(x[[1]], 'Splits')) {
+  } else if (inherits(x[[1]], "Splits")) {
     if (is.null(tipLabels)) {
-      tipLabels <- attr(x, 'tip.label')
+      tipLabels <- attr(x, "tip.label")
       if (is.null(tipLabels)) {
-        tipLabels <- attr(x[[1]], 'tip.label')
+        tipLabels <- attr(x[[1]], "tip.label")
       }
     }
     lapply(x, as.Splits, tipLabels = tipLabels, asSplits = asSplits)
@@ -178,7 +180,7 @@ as.Splits.list <- function(x, tipLabels = NULL, asSplits = TRUE, ...) {
 #' @rdname Splits
 #' @export
 as.Splits.matrix <- function(x, tipLabels = NULL, ...) {
-  if (all(c('edge', 'Nnode') %in% rownames(x))) {
+  if (all(c("edge", "Nnode") %in% rownames(x))) {
     col1 <- x[, 1]
     if (is.list(col1)) {
       if (is.null(tipLabels)) {
@@ -187,11 +189,11 @@ as.Splits.matrix <- function(x, tipLabels = NULL, ...) {
           nTip <- dim(col1[["edge"]])[1] - col1[["Nnode"]] + 1L
           tipLabels <- seq_len(nTip)
           x <- rbind(x, replicate(ncol(x), list(tip.label = tipLabels)))
-          rownames(x)[nrow(x)] <- 'tip.label'
+          rownames(x)[nrow(x)] <- "tip.label"
         }
       }
       lapply(seq_len(ncol(x)), function(i) {
-        as.Splits(structure(x[, i], class = 'phylo'), tipLabels = tipLabels)
+        as.Splits(structure(x[, i], class = "phylo"), tipLabels = tipLabels)
       })
     } else {
       stop("Unsupported matrix. Columns should correspond to trees.")
@@ -215,7 +217,7 @@ as.Splits.logical <- function(x, tipLabels = NULL, ...) {
     if (is.null(tipLabels)) {
       tipLabels <- TipLabels(x)
       if (is.null(tipLabels)) {
-        tipLabels <- paste0('t', seq_len(nTip))
+        tipLabels <- paste0("t", seq_len(nTip))
       }
     } else {
       tipLabels <- TipLabels(tipLabels)
@@ -224,14 +226,14 @@ as.Splits.logical <- function(x, tipLabels = NULL, ...) {
     structure(matrix(packBits(c(x, logical((8L - nTip) %% 8))), nrow = 1L),
               nTip = nTip,
               tip.label = tipLabels,
-              class = 'Splits')
+              class = "Splits")
   } else {
     if (is.null(tipLabels)) {
       tipLabels <- TipLabels(x)
     }
     nTip <- dimX[2]
     if (is.null(tipLabels)) {
-      tipLabels <- paste0('t', seq_len(nTip))
+      tipLabels <- paste0("t", seq_len(nTip))
     }
 
     nBin <- (nTip %% 8 != 0) + (nTip / 8)
@@ -241,15 +243,37 @@ as.Splits.logical <- function(x, tipLabels = NULL, ...) {
              byrow = TRUE, dimnames = list(rownames(x), NULL)),
       nTip = nTip,
       tip.label = tipLabels,
-      class = 'Splits'
+      class = "Splits"
     )
   }
 }
 
 #' @rdname Splits
 #' @export
-as.logical.Splits <- function(x, tipLabels = attr(x, 'tip.label'), ...) {
-  nTip <- attr(x, 'nTip')
+as.Splits.character <- function(x, tipLabels = NULL, ...) {
+  nTip <- nchar(x[1])
+  
+  if (is.null(tipLabels)) {
+    tipLabels <- TipLabels(x)
+    if (length(tipLabels) == 1 && tipLabels == x) {
+      tipLabels <- paste0("t", seq_len(nTip))
+    }
+  } else {
+    tipLabels <- TipLabels(tipLabels)
+  }
+  
+  sp <- .vapply(gregexpr("*", x, fixed = TRUE), tabulate, integer(nTip), nTip) > 0
+  structure(t(.apply(sp, 2, as.Splits.logical)),
+    nTip = nTip,
+    tip.label = tipLabels,
+    class = "Splits"
+  )
+}
+
+#' @rdname Splits
+#' @export
+as.logical.Splits <- function(x, tipLabels = attr(x, "tip.label"), ...) {
+  nTip <- attr(x, "nTip")
   if (dim(x)[1] == 0) {
     ret <- matrix(logical(0), 0, nTip)
   } else {
@@ -263,11 +287,11 @@ as.logical.Splits <- function(x, tipLabels = attr(x, 'tip.label'), ...) {
 #' @family Splits operations
 #' @export
 print.Splits <- function(x, details = FALSE, ...) {
-  nTip <- attr(x, 'nTip')
-  tipLabels <- attr(x, 'tip.label')
+  nTip <- attr(x, "nTip")
+  tipLabels <- attr(x, "tip.label")
   trivial <- TrivialSplits(x)
   cat(dim(x)[1], "bipartition", ifelse(dim(x)[1] == 1, "split", "splits"),
-      if(any(trivial)) paste0('(', sum(trivial), ' trivial)'),
+      if(any(trivial)) paste0("(", sum(trivial), " trivial)"),
       "dividing", nTip,
       ifelse(is.null(tipLabels), "unlabelled tips.",
              paste("tips,", tipLabels[1], "..", tipLabels[nTip]))
@@ -278,52 +302,84 @@ print.Splits <- function(x, details = FALSE, ...) {
 
       nameLengths <- vapply(splitNames, nchar, 0)
       namePads <- vapply(nameLengths, function(thisLength)
-        paste0(rep.int(' ', max(nameLengths) - thisLength), collapse=''), character(1))
+        paste0(rep.int(" ", max(nameLengths) - thisLength), collapse=""), character(1))
       splitNames <- paste0(splitNames, namePads)
     } else {
       splitNames <- character(length(x))
       nameLengths = 0L
     }
-    cat("\n ", paste0(rep.int(' ', max(nameLengths)), collapse = ''),
-        paste0(rep_len(c(1:9, ' '), nTip), collapse = ''))
+    cat("\n ", paste0(rep.int(" ", max(nameLengths)), collapse = ""),
+        paste0(rep_len(c(1:9, " "), nTip), collapse = ""))
 
     for (i in seq_len(dim(x)[1])) {
       split <- x[i, , drop = FALSE]
-      cat("\n", splitNames[i], '',
-          paste(ifelse(as.logical(rawToBits(split)[seq_len(nTip)]), '*', '.'),
-                collapse = ''))
+      cat("\n", splitNames[i], "",
+          paste(ifelse(as.logical(rawToBits(split)[seq_len(nTip)]), "*", "."),
+                collapse = ""))
     }
   }
 }
 
+#' @family Splits operations
+#' @importFrom utils head
+#' @export
+head.Splits <- function(x, n = 6L, ...) {
+  if (n < 0) {
+    n <- max(0L, length(x) + n)
+  }
+  if (length(x) > n) {
+    x[[seq_len(n)]]
+  } else {
+    x
+  }
+}
+
+#' @family Splits operations
+#' @importFrom utils tail
+#' @export
+tail.Splits <- function(x, n = 6L, ...) {
+  if (n < 0) {
+    n <- max(0L, length(x) + n)
+  }
+  if (length(x) > n) {
+    x[[length(x) + 1L - rev(seq_len(n))]]
+  } else {
+    x
+  }
+}
 
 #' @family Splits operations
 #' @export
 summary.Splits <- function(object, ...) {
   print(object, details = TRUE, ...)
-  nTip <- attr(object, 'nTip')
-  if (is.null(attr(object, 'tip.label'))) {
+  nTip <- attr(object, "nTip")
+  if (is.null(attr(object, "tip.label"))) {
     cat("\n\nTips not labelled.")
   } else {
-    cat("\n\n", paste0("Tip ", seq_len(nTip), ": ", attr(object, 'tip.label'),
-                     "\t", c(character(4L), '\n')[seq_len(min(nTip, 5L))]))
+    cat("\n\n", paste0("Tip ", seq_len(nTip), ": ", attr(object, "tip.label"),
+                     "\t", c(character(4L), "\n")[seq_len(min(nTip, 5L))]))
   }
 }
 
 #' @family Splits operations
 #' @export
-names.Splits <- rownames
+names.Splits <- function(x) rownames(x)
+
+
+#' @family Splits operations
+#' @export
+`names<-.Splits` <- `rownames<-`
 
 
 #' @family Splits operations
 #' @export
 as.character.Splits <- function(x, ...) {
-  tipLabels <- attr(x, 'tip.label')
-  nTip <- attr(x, 'nTip')
+  tipLabels <- attr(x, "tip.label")
+  nTip <- attr(x, "nTip")
 
   apply(as.logical(x), 1L, function(inSplit) {
-    paste0(paste(tipLabels[inSplit], collapse=' '), ' | ',
-           paste(tipLabels[!inSplit], collapse=' '))
+    paste0(paste(tipLabels[inSplit], collapse=" "), " | ",
+           paste(tipLabels[!inSplit], collapse=" "))
   })
 
 }
@@ -331,28 +387,21 @@ as.character.Splits <- function(x, ...) {
 #' @family Splits operations
 #' @export
 as.phylo.Splits <- function(x, ...) {
-  ret <- structure(list(edge = splits_to_edge(x, NTip(x)),
-                        Nnode = NA,
-                        tip.label = TipLabels(x)),
-                   order = 'preorder',
-                   class = 'phylo')
-  ret[["Nnode"]] <- dim(ret[["edge"]])[1] + 1 - NTip(ret)
-  ret
+  ret <- .PreorderTree(
+    edge = splits_to_edge(x, NTip(x)),
+    tip.label = TipLabels(x)
+  )
 }
 
-#' @family Splits operations
-#' @export
-names.Splits <- function(x) rownames(x)
-
 #' @family Splits operations
 #' @export
 c.Splits <- function(...) {
   splits <- list(...)
-  nTip <- unique(vapply(splits, attr, 1, 'nTip'))
+  nTip <- unique(vapply(splits, attr, 1, "nTip"))
   if (length(nTip) > 1L) {
     stop("Splits must relate to identical tips.")
   }
-  tips <- lapply(splits, attr, 'tip.label')
+  tips <- lapply(splits, attr, "tip.label")
   if (length(unique(lapply(tips, sort))) > 1L) {
     stop("All splits must bear identical tips")
   }
@@ -363,7 +412,7 @@ c.Splits <- function(...) {
   structure(do.call(rbind, splits),
             nTip = nTip,
             tip.label = tipLabels,
-            class = 'Splits')
+            class = "Splits")
 }
 
 #' @family Splits operations
@@ -524,7 +573,7 @@ rev.Splits <- function(x) {
 #' match(splits1, splits2)
 # Turns base functions into S3 generics that can handle `Splits` objects
 # (as well as `integer64`s).  This follows equivalent functions in the
-# '\pkg{bit64}' package.
+# "\pkg{bit64}" package.
 #
 #' @seealso Corresponding base functions are documented in
 #' [`match()`][base::match].
@@ -590,9 +639,9 @@ setMethod("%in%",
 #' @family Splits operations
 #' @export
 PolarizeSplits <- function(x, pole = 1L) {
-  nTip <- attr(x, 'nTip')
+  nTip <- attr(x, "nTip")
   if (!is.numeric(pole)) {
-    pole <- match(pole, attr(x, 'tip.label'))
+    pole <- match(pole, attr(x, "tip.label"))
   }
   if (is.na(pole)) {
     stop("Could not find `pole` in labels of `x`")
@@ -618,4 +667,3 @@ PolarizeSplits <- function(x, pole = 1L) {
   }
   x
 }
-
