@@ -37,219 +37,6 @@ ApeTime <- function(filepath, format = "double") {
   ifelse(format == "double", as.numeric(as.POSIXct(time, tz = "GMT")), time)
 }
 
-.TntCommands <- function(filepath) {
-  fileText <- readLines(filepath)
-  commands <- strsplit(
-    paste(fileText, collapse = "\UA"), #\UA = \n
-    "\\s*;\\s*")[[1]]
-}
-
-#' Parse TNT Tree
-#'
-#' Read a tree from TNT's parenthetical output.
-#'
-#' [TNT](http://www.lillo.org.ar/phylogeny/tnt/) is software for parsimony
-#' analysis.  Whilst its implementation of tree search is extremely rapid,
-#' analysis of results in TNT is made difficult by its esoteric and scantly
-#' documented scripting language.
-#'
-#' `ReadTntTree()` aims to aid the user by facilitating the import of trees
-#' generated in TNT into R for further analysis.
-#'
-#' The function depends on tree files being saved by TNT in parenthetical
-#' notation, using the TNT command `tsav*`.
-#' Trees are easiest to load into R if taxa have been saved using their names
-#' (TNT command `taxname=`).  In this case, the TNT `.tre` file
-#' contains tip labels and can be parsed directly.  The downside is that the
-#' uncompressed `.tre` files will have a larger file size.
-#'
-#' `ReadTntTree()` can also read `.tre` files in which taxa have been saved
-#' using their numbers (`taxname-`).  Such files contain a hard-coded link to
-#' the matrix file that was used to generate the trees, in the first line of the
-#' `.tre` file.  This poses problems for portability: if the matrix file is
-#' moved, or the `.tre` file is accessed on another computer, the taxon names
-#' may be lost.  As such, it is important to check that the matrix file
-#' exists in the expected location -- if it does not,
-#' either use the `relativePath` argument to point to its new location, or
-#' specify `tipLabels` to manually specify the tip labels.
-#'
-#' `TntText2Tree()` converts text representation of a tree in TNT to an
-#'  object of class `phylo`.
-#'
-#' @param filepath character string specifying path to TNT `.tre` file,
-#' relative to the R working directory (visible with `getwd()`).
-#' @param relativePath (discouraged) character string specifying location of the
-#' matrix file used to generate the TNT results, relative to the current working
-#' directory.  Taxon names will be read from this file if they are not specified
-#'  by `tipLabels`.
-#' @param keepEnd (optional, default 1) integer specifying how many elements of
-#'  the file path to conserve when creating relative path (see examples).
-#' @param tipLabels (optional) character vector specifying the names of the
-#' taxa, in the sequence that they appear in the TNT file.  If not specified,
-#' taxon names will be loaded from the data file linked in the first line of the
-#'  `.tre` file specified in `filepath`.
-#'
-#' @return `ReadTntTree()` returns a tree of class \code{phylo}, corresponding
-#' to the tree in `filepath`, or NULL if no trees are found.
-#'
-#' @examples
-#' # In the examples below, TNT has read a matrix from
-#' # "c:/TreeTools/input/dataset.nex"
-#' # The results of an analysis were written to
-#' # "c:/TreeTools/output/results1.tnt"
-#' #
-#' # results1.tnt will contain a hard-coded reference to
-#' # "c:/TreeTools/input/dataset.nex".
-#'
-#' # On the original machine (but not elsewhere), it would be possible to read
-#' # this hard-coded reference from results.tnt:
-#' # ReadTntTree("output/results1.tnt")
-#'
-#' # These datasets are provided with the "TreeTools" package, which will
-#' # probably not be located at c:/TreeTools on your machine:
-#'
-#' oldWD <- getwd() # Remember the current working directory
-#' setwd(system.file(package = "TreeTools"))
-#'
-#' # If taxon names were saved within the file (using `taxname=` in TNT),
-#' # then our job is easy:
-#' ReadTntTree("extdata/output/named.tre")
-#'
-#' # But if taxa were compressed to numbers (using `taxname-`), we need to
-#' # look up the original matrix in order to dereference the tip names.
-#' #
-#' # We need to extract the relevant file path from the end of the
-#' # hard-coded path in the original file.
-#' #
-#' # We are interested in the last two elements of
-#' # c:/TreeTools/input/dataset.nex
-#' #                2      1
-#' #
-#' # "." means "relative to the current directory"
-#' ReadTntTree("extdata/output/numbered.tre", "./extdata", 2)
-#'
-#' # If working in a lower subdirectory
-#' setwd("./extdata/otherfolder")
-#'
-#' # then it will be necessary to navigate up the directory path with "..":
-#' ReadTntTree("../output/numbered.tre", "..", 2)
-#'
-#'
-#' setwd(oldWD) # Restore original working directory
-#'
-#' TNTText2Tree("(A (B (C (D E ))));")
-#'
-#' @template MRS
-#' @importFrom ape read.tree
-#' @export
-ReadTntTree <- function(filepath, relativePath = NULL, keepEnd = 1L,
-                         tipLabels = NULL) {
-  commands <- .TntCommands(filepath)
-  tread <- grep("^tread\\b", commands, perl = TRUE)
-  if (length(tread) < 1) return(NULL)
-  
-  trees <- c(TntText2Tree(
-    paste(
-      gsub("tread\\s+('[^']*')*\\s*", "", commands[tread]),
-      collapse = "*")))
-
-  if (!any(grepl("[A-z]", trees[[1]]$tip.label))) {
-    if (is.null(tipLabels)) {
-      tipLabels <- rownames(ReadTntCharacters(filepath))
-      if (is.null(tipLabels)) {
-        if (length(tread) > 1) {
-          warning("Multiple tree blocks not fully supported; ",
-                  "please check tip labels and contact \"TreeTools\" ",
-                  "maintainer if necessary")
-        }
-        treadComment <- strsplit(commands[tread[1]], "'", fixed = TRUE)[[1]]
-        filePrefix <- "tree(s) from TNT, for data in "
-        taxonFile <- grep(filePrefix, treadComment, fixed = TRUE)
-        taxonFile <- gsub(filePrefix, "", 
-                          gsub("\\", "/", treadComment[taxonFile], fixed = TRUE),
-                          fixed = TRUE)
-        if (!is.null(relativePath)) {
-          taxonFileParts <- strsplit(taxonFile, "/")[[1]]
-          nParts <- length(taxonFileParts)
-          if (nParts < keepEnd) {
-            stop("Taxon file path (", taxonFile,                                # nocov
-                 ") contains fewer than keepEnd (", keepEnd, ") components.")   # nocov
-          }
-          taxonFile <- paste0(c(relativePath,
-                                taxonFileParts[(nParts + 1L - keepEnd):nParts]),
-                              collapse = "/")
-        }
-        
-        if (length(taxonFile)) {
-          if (!file.exists(taxonFile)) {
-            warning("Cannot find linked data file:\n  ", taxonFile)                 # nocov
-          } else {
-            tipLabels <- rownames(ReadTntCharacters(taxonFile, character_num = 1L))
-            if (is.null(tipLabels)) {
-              # TNT character read failed.  Perhaps taxonFile is in NEXUS format?
-              tipLabels <- rownames(ReadCharacters(taxonFile, character_num = 1L))
-            }
-            if (is.null(tipLabels)) {
-              warning("Could not read taxon names from linked TNT file:\n  ",       # nocov
-                      taxonFile, "\nIs the file in TNT or Nexus format?",           # nocov
-                      " If failing inexplicably, please report:",                   # nocov
-                      "\n  https://github.com/ms609/TreeTools/issues/new")          # nocov
-            }
-          }
-        } else {
-          warning("`filepath` does not link to taxon names; try specifying `tipLabels`")
-          tipLabels <- as.character(seq_len(trees[[1]]$edge[1] - 1) - 1)
-        }
-      }
-    }
-
-    trees <- lapply(trees, function(tree) {
-      tree$tip.label <- tipLabels[as.integer(tree$tip.label) + 1L]
-      tree
-    })
-  }
-
-  # Return:
-  if (length(trees) == 1) {
-    trees[[1]]
-  } else if (length(trees) == 0) {
-    NULL                                                                        # nocov
-  } else {
-    class(trees) <- "multiPhylo"
-    trees
-  }
-
-}
-
-#' @rdname ReadTntTree
-#' @param treeText Character string describing one or more trees,
-#' in the parenthetical format output by TNT.
-#' @export
-TntText2Tree <- function(treeText) {
-  treeText <- paste(strsplit(treeText, "\\s*\\*\\s*", perl = TRUE)[[1]], ";")
-  treeText <- gsub(";(\\s*;)+", ";", treeText)
-  treeText <- gsub("\\s*([\\w'\\.\\-]+)\\s*", "\\1,", treeText, perl = TRUE)
-  treeText <- gsub("\\)\\s*\\(", "),(", treeText, perl = TRUE)
-  treeText <- gsub(",)", ")", treeText, fixed = TRUE)
-  
-  tr <- read.tree(text = treeText)
-  if (inherits(tr, "multiPhylo")) {
-    tr[] <- lapply(tr, function (tree) {
-      tree$tip.label[] <- Unquote(tree$tip.label)
-      tree
-    })
-  } else if (inherits(tr, "phylo")) {
-    tr$tip.label[] <- Unquote(tr$tip.label)
-  }
-
-  # Return:
-  tr
-}
-
-#' @rdname ReadTntTree
-#' @export
-TNTText2Tree <- TntText2Tree
-
 #' Extract taxa from a matrix block
 #'
 #' Extract leaf labels and character states from a Nexus-formatted matrix.
