@@ -19,14 +19,14 @@
 #' TipsInSplits(splits)
 #'
 #' plot(tree)
-#' LabelSplits(tree, as.character(splits), frame = 'none', pos = 3L, cex = 0.7)
-#' LabelSplits(tree, TipsInSplits(splits), unit = ' tips', frame = 'none',
+#' LabelSplits(tree, as.character(splits), frame = "none", pos = 3L, cex = 0.7)
+#' LabelSplits(tree, TipsInSplits(splits), unit = " tips", frame = "none",
 #'             pos = 1L)
 #'
 #' @family Splits operations
 #' @export
 TipsInSplits <- function(splits, keep.names = TRUE, smallest = FALSE, ...) {
-  UseMethod('TipsInSplits')
+  UseMethod("TipsInSplits")
 }
 
 #' @rdname TipsInSplits
@@ -56,11 +56,11 @@ TipsInSplits.phylo <- function(splits, keep.names = TRUE, smallest = FALSE,
 
 #' @rdname TipsInSplits
 #' @return `SplitImbalance()` returns a named vector of integers, specifying the
-#' number of leaves within a split that are not 'balanced' by a leaf outside it;
+#' number of leaves within a split that are not "balanced" by a leaf outside it;
 #' i.e. a split that divides leaves evenly has an imbalance of zero; one that
 #' splits two tips from ten has an imbalance of 10 - 2 = 8.
 #' @export
-SplitImbalance <- function(splits, keep.names = TRUE, ...) UseMethod('SplitImbalance')
+SplitImbalance <- function(splits, keep.names = TRUE, ...) UseMethod("SplitImbalance")
 
 #' @rdname TipsInSplits
 #' @export
