@@ -1,6 +1,6 @@
 test_that("AddUnconstrained() works", {
   tips <- letters[1:9]
-  constraint <- StringToPhyDat('0000?1111 000111111 0000??110', tips, FALSE)
+  constraint <- StringToPhyDat("0000?1111 000111111 0000??110", tips, FALSE)
   expect_equal(AddUnconstrained(constraint, letters[10:12], FALSE),
                PhyDatToMatrix(AddUnconstrained(constraint, letters[10:12], TRUE)))
   expect_equal(PhyDatToMatrix(AddUnconstrained(constraint, letters[10:12], TRUE)),
@@ -10,26 +10,26 @@ test_that("AddUnconstrained() works", {
 test_that("ImposeConstraint() works", {
   tips <- letters[1:9]
   tree <- as.phylo(1, 9, tips)
-  constraint <- StringToPhyDat('0000?1111 000111111 0000??110', tips, FALSE)
+  constraint <- StringToPhyDat("0000?1111 000111111 0000??110", tips, FALSE)
   expect_true(all.equal(
     ImposeConstraint(tree, constraint),
-    read.tree(text = '((a, (b, c)), (d, (e, (f, (i, (g, h))))));')))
+    read.tree(text = "((a, (b, c)), (d, (e, (f, (i, (g, h))))));")))
 
   expect_equal(ImposeConstraint(tree, constraint),
                ImposeConstraint(tree, PhyDatToMatrix(constraint)))
 
-  constraint <- StringToPhyDat('00001111 00011111 0000?110', tips[-5], FALSE)
+  constraint <- StringToPhyDat("00001111 00011111 0000?110", tips[-5], FALSE)
   expect_true(all.equal(
     ImposeConstraint(tree, constraint),
-    read.tree(text = '((a, (b, c)), (d, (e, (f, (i, (g, h))))));')))
+    read.tree(text = "((a, (b, c)), (d, (e, (f, (i, (g, h))))));")))
 
   constraint <- MatrixToPhyDat(matrix(
-    c(0, 0, '?', '?', 1, 1,
-      1, 1,   1, '?', 0, 0), ncol = 2,
+    c(0, 0, "?", "?", 1, 1,
+      1, 1,   1, "?", 0, 0), ncol = 2,
     dimnames = list(letters[1:6], NULL)))
 
   expect_warning({out <- ImposeConstraint(NJTree(constraint), constraint)})
-  expect_true(inherits(out, 'phylo'))
+  expect_true(inherits(out, "phylo"))
 
   # Need to collapse splits intelligently to avoid error.  From Joe Moysiuk.
   constraint <- MatrixToPhyDat(
