@@ -11,21 +11,21 @@ test_that("Failures are graceful", {
 })
 
 test_that("Edge cases handled", {
-  expect_equal(SingleTaxonTree('singleton'), as.phylo(0, 1, 'singleton'))
+  expect_equal(SingleTaxonTree("singleton"), as.phylo(0, 1, "singleton"))
   expect_true(all.equal(BalancedTree(2), as.phylo(0, 2)))
-  expect_equal(structure(as.integer64(0L), nTip = 2L, tip.label = c('t1', 't2'),
-                         class = c('TreeNumber', 'integer64')),
+  expect_equal(structure(as.integer64(0L), nTip = 2L, tip.label = c("t1", "t2"),
+                         class = c("TreeNumber", "integer64")),
                as.TreeNumber(as.phylo(0, 2)))
-  expect_equal(structure(integer64(1), nTip = 1L, tip.label = 't1',
-                         class = c('TreeNumber', 'integer64')),
+  expect_equal(structure(integer64(1), nTip = 1L, tip.label = "t1",
+                         class = c("TreeNumber", "integer64")),
                as.TreeNumber(SingleTaxonTree()))
 })
 
-test_that('Trees generated okay', {
+test_that("Trees generated okay", {
   expect_true(all.equal(
     Preorder(ape::read.tree(text=("(0, (4, ((1, 5), (2, 3))));"))),
     as.phylo(10, 6, 0:5)))
-  expect_equal(as.TreeNumber('10', 6, 0:5),
+  expect_equal(as.TreeNumber("10", 6, 0:5),
                as.TreeNumber(as.phylo.numeric(10, 6, 0:5)))
   Test <- function(i, nTip) {
     expect_equal(as.integer64(i),
@@ -38,9 +38,9 @@ test_that('Trees generated okay', {
   xx <- lapply(floor(runif(48) * NUnrooted(12)), Test, 12)
 
   nTip <- 14L
-  treeNumber <- as.TreeNumber('123456789876', nTip, seq_len(nTip) - 1L)
+  treeNumber <- as.TreeNumber("123456789876", nTip, seq_len(nTip) - 1L)
   expect_equal(treeNumber, as.TreeNumber(as.phylo(treeNumber)))
-  treeNumber <- as.TreeNumber('123456789876', nTip, seq_len(nTip) - 1L)
+  treeNumber <- as.TreeNumber("123456789876", nTip, seq_len(nTip) - 1L)
   expect_equal(treeNumber, as.TreeNumber(as.phylo(treeNumber)))
   
   expect_equal
